Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client represents the client used for making http requests, including the session if used.
func Login ¶
Login will login to an account with the provided credentials and give you a Client with user info back
func (*Client) GetDomains ¶
GetDomains gets an array of uploadable domains
func (*Client) UpdateAccountInfo ¶
UpdateAccountInfo is a wrapper for GetAccountInfo() that replaces user info automatically
type Domain ¶
type Domain struct {
Hostname string `json:"domain"`
ID int `json:"id"`
Public bool `json:"public"`
System bool `json:"system"`
OwnerID int `json:"ownerId"`
Disabled bool `json:"disabled"`
}
Domain represents a pxl.blue host.
type User ¶
type User struct {
ID int `json:"id"`
Username string `json:"username"`
Email string `json:"Email"`
RegistrationDate string `json:"registrationDate"`
LastLogin string `json:"lastLogin"`
UploadKey string `json:"uploadKey"`
RegistrationIP string `json:"registrationIp"`
Moderator bool `json:"moderator"`
Admin bool `json:"admin"`
Banned bool `json:"banned"`
BanReason string `json:"banReason"`
ImageCount int `json:"imageCount"`
}
User holds all of the information about a user that is accessible from the profile page
Source Files
¶
- account.go
- client.go
- http.go
- public.go
- structs.go
- upload.go
Click to show internal directories.
Click to hide internal directories.